@@ -23,6 +23,7 @@
 #include <string.h>
 #include <glib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtk.h>
 
 #include "games-find-file.h"
 #include "games-files.h"
@@ -30,6 +31,10 @@
 
 #include "games-card-theme.h"
 
+struct _GamesCardThemeClass {
+  GObjectClass parent_class;
+};
+
 struct _GamesCardTheme {
   GObject parent;
 
@@ -61,9 +66,9 @@ struct _GamesCardTheme {
   guint subrender : 1;
   guint prescaled : 1;
 
-  guint antialias_set : 1;
-  guint antialias : 2; /* enough bits for cairo_antialias_t */
-  guint subpixel_order : 3; /* enough bits for cairo_subpixel_order_t */
+#if GTK_CHECK_VERSION (2, 10, 0)
+  cairo_font_options_t *font_options;
+#endif
 };
 
 enum {
@@ -72,6 +77,13 @@ enum {
   PROP_THEME_DIRECTORY
 };
 
+enum {
+  CHANGED,
+  LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL];
+
 /* FIXMEchpe: use uninstalled data dir for rendering the card theme! */
 #define SLOTDIR  PKGDATADIR "/pixmaps"
 
@@ -181,10 +193,11 @@ games_card_theme_load_theme_scalable (GamesCardTheme * theme,
   if (!preimage)
     goto out;
 
-  if (theme->antialias_set) {
-    games_preimage_set_antialias (preimage, theme->antialias,
-                                  theme->subpixel_order);
+#if GTK_CHECK_VERSION (2, 10, 0)
+  if (theme->font_options) {
+    games_preimage_set_font_options (preimage, theme->font_options);
   }
+#endif
 
   theme->theme_data.scalable.cards_preimage = preimage;
   theme->prescaled = games_preimage_is_scalable (preimage);
@@ -202,9 +215,12 @@ games_card_theme_load_theme_scalable (GamesCardTheme * theme,
   g_free (path);
   g_return_val_if_fail (theme->theme_data.scalable.slot_preimage != NULL, FALSE);
 
-  if (theme->antialias_set)
-    games_preimage_set_antialias (theme->theme_data.scalable.slot_preimage,
-                                  theme->antialias, theme->subpixel_order);
+#if GTK_CHECK_VERSION (2, 10, 0)
+  if (theme->font_options) {
+    games_preimage_set_font_options (theme->theme_data.scalable.slot_preimage,
+                                     theme->font_options);
+  }
+#endif
 
   /* Use subrendering by default, but allow to override with the env var */
   theme->subrender = TRUE;
@@ -525,6 +541,12 @@ games_card_theme_finalize (GObject * object)
   g_free (theme->theme_name);
   g_free (theme->theme_dir);
 
+#if GTK_CHECK_VERSION (2, 10, 0)
+  if (theme->font_options) {
+    cairo_font_options_destroy (theme->font_options);
+  }
+#endif
+
   G_OBJECT_CLASS (games_card_theme_parent_class)->finalize (object);
 }
 
@@ -571,13 +593,31 @@ games_card_theme_set_property (GObject * object,
 }
 
 static void
-games_card_theme_class_init (GamesCardThemeClass * class)
+games_card_theme_class_init (GamesCardThemeClass * klass)
 {
-  GObjectClass *gobject_class = G_OBJECT_CLASS (class);
+  GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
   gobject_class->set_property = games_card_theme_set_property;
   gobject_class->finalize = games_card_theme_finalize;
 
+  /**
+   * GamesCardTheme:changed:
+   * @theme: the object on which the signal is emitted
+   *
+   * The ::changed signal is emitted when the card theme has
+   * changed in any way that makes it necessary to re-render
+   * any displayed or cached images.
+   */
+  signals[CHANGED] =
+    g_signal_newv ("changed",
+                   G_TYPE_FROM_CLASS (klass),
+                   (GSignalFlags) (G_SIGNAL_RUN_LAST),
+                   NULL,
+                   NULL, NULL,
+                   g_cclosure_marshal_VOID__VOID,
+                   G_TYPE_NONE,
+                   0, NULL);
+
   g_object_class_install_property
     (gobject_class,
      PROP_SCALABLE,
@@ -617,33 +657,42 @@ games_card_theme_new (const char *theme_dir, gboolean scalable)
                        NULL);
 }
 
+#if GTK_CHECK_VERSION (2, 10, 0)
+
 /**
- * games_card_theme_set_antialias:
+ * games_card_theme_set_font_options:
  * @theme:
- * @antialias: the antialiasing mode to use (see @cairo_antialias_t)
- * @subpixel_order: the subpixel order to use (see @cairo_subpixel_order_t)
- * if @antialias is %CAIRO_ANTIALIAS_SUBPIXEL 
+ * @font_options: the #cairo_font_options_t to use
  *
- * Turns on antialising of cards, if using a scalable theme.
+ * Sets the font options to use when drawing the card images.
  */
 void
-games_card_theme_set_antialias (GamesCardTheme * theme,
-                                guint antialias, guint subpixel_order)
+games_card_theme_set_font_options (GamesCardTheme * theme,
+                                   const cairo_font_options_t *font_options)
 {
   g_return_if_fail (GAMES_IS_CARD_THEME (theme));
 
-  if (theme->antialias_set &&
-      theme->antialias == antialias &&
-      theme->subpixel_order == subpixel_order)
+  if (font_options &&
+      theme->font_options &&
+      cairo_font_options_equal (font_options, theme->font_options))
     return;
 
-  theme->antialias_set = TRUE;
-  theme->antialias = antialias;
-  theme->subpixel_order = subpixel_order;
+  if (theme->font_options) {
+    cairo_font_options_destroy (theme->font_options);
+  }
+
+  if (font_options) {
+    theme->font_options = cairo_font_options_copy (font_options);
+  } else {
+    theme->font_options = NULL;
+  }
 
   games_card_theme_clear_source_pixbuf (theme);
+  g_signal_emit (theme, signals[CHANGED], 0);
 }
 
+#endif /* GTK 2.10.0 */
+
 /**
  * games_card_theme_set_theme:
  * @theme:
@@ -669,6 +718,7 @@ games_card_theme_set_theme (GamesCardTheme * theme, const gchar * theme_name)
 
   games_card_theme_clear_source_pixbuf (theme);
   games_card_theme_clear_theme_data (theme);
+  g_signal_emit (theme, signals[CHANGED], 0);
 
   theme->card_size.width = theme->card_size.height = theme->slot_size.width =
     theme->slot_size.width = -1;
@@ -715,8 +765,8 @@ games_card_theme_set_size (GamesCardTheme * theme,
     return FALSE;
   }
 
-  if ((width == theme->slot_size.width)
-      && (height == theme->slot_size.height))
+  if ((width == theme->slot_size.width) &&
+      (height == theme->slot_size.height))
     return FALSE;
 
   theme->slot_size.width = width;
@@ -810,6 +860,7 @@ games_card_theme_set_size (GamesCardTheme * theme,
   }
 
   games_card_theme_clear_source_pixbuf (theme);
+  g_signal_emit (theme, signals[CHANGED], 0);
 
   return TRUE;
 }
