@@ -940,7 +940,7 @@ about_callback (void)
 			 "version", VERSION,
 			 "comments",
 			 _("A matching game played with Mahjongg tiles.\n\nMahjongg is a part of GNOME Games."),
-			 "copyright", "Copyright \xc2\xa9 1998-2007 Free Software Foundation, Inc.",
+			 "copyright", "Copyright \xc2\xa9 1998-2008 Free Software Foundation, Inc.",
 			 "license", license,
                          "wrap-license", TRUE,
                          "authors", authors,
@@ -1011,8 +1011,8 @@ init_game (void)
 {
   gchar *newtitle;
 
-  newtitle = g_strdup_printf (_("%s - %s"), _("Mahjongg"),
-			      Q_ (maps[mapset].name));
+  /* Translators: This is the window title for Mahjongg which contains the map name, e.g. 'Mahjongg - Red Dragon' */
+  newtitle = g_strdup_printf (_("Mahjongg - %s"), Q_ (maps[mapset].name));
   gtk_window_set_title (GTK_WINDOW (window), newtitle);
   g_free (newtitle);
 
